Hello community,

here is the log from the commit of package kauth for openSUSE:Leap:15.2 checked 
in at 2020-06-17 11:34:56
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Leap:15.2/kauth (Old)
 and      /work/SRC/openSUSE:Leap:15.2/.kauth.new.3606 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "kauth"

Wed Jun 17 11:34:56 2020 rev:69 rq:814418 version:5.71.0

Changes:
--------
--- /work/SRC/openSUSE:Leap:15.2/kauth/kauth.changes    2020-05-12 
11:38:46.188547162 +0200
+++ /work/SRC/openSUSE:Leap:15.2/.kauth.new.3606/kauth.changes  2020-06-17 
11:36:09.503818622 +0200
@@ -1,0 +2,10 @@
+Sun Jun  7 08:06:19 UTC 2020 - Christophe Giboudeaux <[email protected]>
+
+- Update to 5.71.0
+  * New feature release
+  * For more details please see:
+  * https://kde.org/announcements/kde-frameworks-5.71.0
+- Changes since 5.70.0:
+  * Use ECMGenerateExportHeader to manage deprecated API better
+
+-------------------------------------------------------------------

Old:
----
  kauth-5.70.0.tar.xz
  kauth-5.70.0.tar.xz.sig

New:
----
  kauth-5.71.0.tar.xz
  kauth-5.71.0.tar.xz.sig

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ kauth.spec ++++++
--- /var/tmp/diff_new_pack.JxNTzC/_old  2020-06-17 11:36:09.847819662 +0200
+++ /var/tmp/diff_new_pack.JxNTzC/_new  2020-06-17 11:36:09.847819662 +0200
@@ -17,14 +17,14 @@
 
 
 %define lname   libKF5Auth5
-%define _tar_path 5.70
+%define _tar_path 5.71
 # Full KF5 version (e.g. 5.33.0)
 %{!?_kf5_version: %global _kf5_version %{version}}
 # Last major and minor KF5 version (e.g. 5.33)
 %{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | 
awk -F. '{print $1"."$2}')}
 %bcond_without lang
 Name:           kauth
-Version:        5.70.0
+Version:        5.71.0
 Release:        0
 Summary:        Framework which lets applications perform actions as a 
privileged user
 License:        LGPL-2.1-or-later


++++++ kauth-5.70.0.tar.xz -> kauth-5.71.0.tar.xz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/.arcconfig new/kauth-5.71.0/.arcconfig
--- old/kauth-5.70.0/.arcconfig 2020-05-03 00:14:56.000000000 +0200
+++ new/kauth-5.71.0/.arcconfig 1970-01-01 01:00:00.000000000 +0100
@@ -1,3 +0,0 @@
-{
-  "phabricator.uri" : "https://phabricator.kde.org/";
-}
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/CMakeLists.txt 
new/kauth-5.71.0/CMakeLists.txt
--- old/kauth-5.70.0/CMakeLists.txt     2020-05-03 00:14:56.000000000 +0200
+++ new/kauth-5.71.0/CMakeLists.txt     2020-06-07 20:22:26.000000000 +0200
@@ -1,11 +1,11 @@
 cmake_minimum_required(VERSION 3.5)
 
-set(KF5_VERSION "5.70.0") # handled by release scripts
-set(KF5_DEP_VERSION "5.70.0") # handled by release scripts
+set(KF5_VERSION "5.71.0") # handled by release scripts
+set(KF5_DEP_VERSION "5.71.0") # handled by release scripts
 project(KAuth VERSION ${KF5_VERSION})
 
 include(FeatureSummary)
-find_package(ECM 5.70.0  NO_MODULE)
+find_package(ECM 5.71.0  NO_MODULE)
 set_package_properties(ECM PROPERTIES TYPE REQUIRED DESCRIPTION "Extra CMake 
Modules." URL "https://commits.kde.org/extra-cmake-modules";)
 feature_summary(WHAT REQUIRED_PACKAGES_NOT_FOUND 
FATAL_ON_MISSING_REQUIRED_PACKAGES)
 
@@ -24,7 +24,7 @@
 set(CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} ${CMAKE_CURRENT_SOURCE_DIR}/cmake)
 
 
-include(GenerateExportHeader)
+include(ECMGenerateExportHeader)
 include(ECMSetupVersion)
 include(ECMGenerateHeaders)
 include(ECMQtDeclareLoggingCategory)
@@ -32,6 +32,8 @@
 include(ECMPoQmTools)
 include(ECMAddQch)
 
+set(EXCLUDE_DEPRECATED_BEFORE_AND_AT 0 CACHE STRING "Control the range of 
deprecated API excluded from the build [default=0].")
+
 option(BUILD_QCH "Build API documentation in QCH format (for e.g. Qt 
Assistant, Qt Creator & KDevelop)" OFF)
 add_feature_info(QCH ${BUILD_QCH} "API documentation in QCH format (for e.g. 
Qt Assistant, Qt Creator & KDevelop)")
 
@@ -54,7 +56,7 @@
     ecm_install_po_files_as_qm(po)
 endif()
 add_definitions(-DQT_DISABLE_DEPRECATED_BEFORE=0x050d00)
-add_definitions(-DKF_DISABLE_DEPRECATED_BEFORE_AND_AT=0x054400)
+add_definitions(-DKF_DISABLE_DEPRECATED_BEFORE_AND_AT=0x054700)
 add_definitions(-DQT_NO_FOREACH)
 add_subdirectory(src)
 if(TARGET Qt5::Widgets)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/autotests/CMakeLists.txt 
new/kauth-5.71.0/autotests/CMakeLists.txt
--- old/kauth-5.70.0/autotests/CMakeLists.txt   2020-05-03 00:14:56.000000000 
+0200
+++ new/kauth-5.71.0/autotests/CMakeLists.txt   2020-06-07 20:22:26.000000000 
+0200
@@ -38,6 +38,15 @@
     PUBLIC KAUTHCORE_STATIC_DEFINE=1
     PUBLIC KAUTH_STATIC_DEFINE=1
 )
+# have to manually duplicate logic of flags set by ecm_generate_expoirt_header 
on the library
+ecm_export_header_format_version(${EXCLUDE_DEPRECATED_BEFORE_AND_AT}
+    CURRENT_VERSION ${KF5_VERSION}
+    HEXNUMBER_VAR kauthcore_tests_no_deprecated_before_and_at
+)
+target_compile_definitions(kauth_tests_static
+    PUBLIC 
"KAUTHCORE_DISABLE_DEPRECATED_BEFORE_AND_AT=${kauthcore_tests_no_deprecated_before_and_at}"
+    PUBLIC 
"KAUTHCORE_DEPRECATED_WARNINGS_SINCE=${kauthcore_tests_no_deprecated_before_and_at}"
+)
 ecm_mark_as_test(kauth_tests_static)
 
 target_include_directories(kauth_tests_static
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/autotests/SetupActionTest.cpp 
new/kauth-5.71.0/autotests/SetupActionTest.cpp
--- old/kauth-5.70.0/autotests/SetupActionTest.cpp      2020-05-03 
00:14:56.000000000 +0200
+++ new/kauth-5.71.0/autotests/SetupActionTest.cpp      2020-06-07 
20:22:26.000000000 +0200
@@ -37,6 +37,9 @@
     void init() {}
 
     void testNonExistentAction();
+#if KAUTHCORE_BUILD_DEPRECATED_SINCE(5, 71)
+    void testBasicActionPropertiesDeprecated();
+#endif
     void testBasicActionProperties();
     void testUserAuthorization();
     void testAuthorizationFail();
@@ -72,14 +75,17 @@
     QVERIFY(!action.isValid());
 }
 
-void SetupActionTest::testBasicActionProperties()
+#if KAUTHCORE_BUILD_DEPRECATED_SINCE(5, 71)
+void SetupActionTest::testBasicActionPropertiesDeprecated()
 {
     emit changeCapabilities(KAuth::AuthBackend::AuthorizeFromHelperCapability 
| KAuth::AuthBackend::CheckActionExistenceCapability);
+    KAuth::Action::DetailsMap 
detailsMap{{KAuth::Action::AuthDetail::DetailOther, QLatin1String("details")}};
     KAuth::Action action(QLatin1String("always.authorized"), 
QLatin1String("details"));
     QVERIFY(action.isValid());
 
     QCOMPARE(action.name(), QLatin1String("always.authorized"));
     QCOMPARE(action.details(), QLatin1String("details"));
+    QCOMPARE(action.detailsV2(), detailsMap);
     QVERIFY(!action.hasHelper());
     QVERIFY(action.helperId().isEmpty());
     QCOMPARE(action.status(), KAuth::Action::AuthorizedStatus);
@@ -100,6 +106,48 @@
     QVERIFY(action.isValid());
     QCOMPARE(action.name(), QLatin1String("i.do.not.exist"));
     QCOMPARE(action.details(), QLatin1String("details"));
+    QCOMPARE(action.detailsV2(), detailsMap);
+    QVERIFY(!action.hasHelper());
+    QVERIFY(action.helperId().isEmpty());
+    QCOMPARE(action.status(), KAuth::Action::InvalidStatus);
+}
+#endif
+
+void SetupActionTest::testBasicActionProperties()
+{
+    emit changeCapabilities(KAuth::AuthBackend::AuthorizeFromHelperCapability 
| KAuth::AuthBackend::CheckActionExistenceCapability);
+    KAuth::Action::DetailsMap 
detailsMap{{KAuth::Action::AuthDetail::DetailOther, QLatin1String("details")}};
+    KAuth::Action action(QLatin1String("always.authorized"), detailsMap);
+    QVERIFY(action.isValid());
+
+    QCOMPARE(action.name(), QLatin1String("always.authorized"));
+#if KAUTHCORE_BUILD_DEPRECATED_SINCE(5, 71)
+    QCOMPARE(action.details(), QLatin1String("details"));
+#endif
+    QCOMPARE(action.detailsV2(), detailsMap);
+    QVERIFY(!action.hasHelper());
+    QVERIFY(action.helperId().isEmpty());
+    QCOMPARE(action.status(), KAuth::Action::AuthorizedStatus);
+
+    QVERIFY(action.arguments().isEmpty());
+    QVariantMap args;
+    args.insert(QLatin1String("akey"), QVariant::fromValue(42));
+    action.setArguments(args);
+    QCOMPARE(action.arguments(), args);
+
+    action.setName(QLatin1String("i.do.not.exist"));
+    QVERIFY(!action.isValid());
+
+    emit changeCapabilities(KAuth::AuthBackend::NoCapability);
+
+    action = KAuth::Action(QLatin1String("i.do.not.exist"), detailsMap);
+
+    QVERIFY(action.isValid());
+    QCOMPARE(action.name(), QLatin1String("i.do.not.exist"));
+#if KAUTHCORE_BUILD_DEPRECATED_SINCE(5, 71)
+    QCOMPARE(action.details(), QLatin1String("details"));
+#endif
+    QCOMPARE(action.detailsV2(), detailsMap);
     QVERIFY(!action.hasHelper());
     QVERIFY(action.helperId().isEmpty());
     QCOMPARE(action.status(), KAuth::Action::InvalidStatus);
@@ -109,7 +157,8 @@
 {
     emit 
changeCapabilities(KAuth::AuthBackend::CheckActionExistenceCapability);
 
-    KAuth::Action action(QLatin1String("requires.auth"), 
QLatin1String("details"));
+    KAuth::Action::DetailsMap 
detailsMap{{KAuth::Action::AuthDetail::DetailOther, QLatin1String("details")}};
+    KAuth::Action action(QLatin1String("requires.auth"), detailsMap);
     QVERIFY(action.isValid());
 
     QCOMPARE(action.status(), KAuth::Action::AuthRequiredStatus);
@@ -136,7 +185,8 @@
 {
     emit changeCapabilities(KAuth::AuthBackend::CheckActionExistenceCapability 
| KAuth::AuthBackend::AuthorizeFromClientCapability);
 
-    KAuth::Action action(QLatin1String("doomed.to.fail"), 
QLatin1String("details"));
+    KAuth::Action::DetailsMap 
detailsMap{{KAuth::Action::AuthDetail::DetailOther, QLatin1String("details")}};
+    KAuth::Action action(QLatin1String("doomed.to.fail"), detailsMap);
     QVERIFY(action.isValid());
 
     QCOMPARE(action.status(), KAuth::Action::DeniedStatus);
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/docs/Doxyfile.local 
new/kauth-5.71.0/docs/Doxyfile.local
--- old/kauth-5.70.0/docs/Doxyfile.local        1970-01-01 01:00:00.000000000 
+0100
+++ new/kauth-5.71.0/docs/Doxyfile.local        2020-06-07 20:22:26.000000000 
+0200
@@ -0,0 +1,8 @@
+### KApiDox Project-specific Overrides File
+
+# define so that deprecated API is not skipped
+PREDEFINED += \
+    "KAUTHCORE_ENABLE_DEPRECATED_SINCE(x, y)=1" \
+    "KAUTHCORE_BUILD_DEPRECATED_SINCE(x, y)=1" \
+    "KAUTHCORE_DEPRECATED_VERSION(x, y, t)=" \
+    "KAUTHCORE_DEPRECATED_VERSION_BELATED(x, y, xt, yt, t)="
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/metainfo.yaml 
new/kauth-5.71.0/metainfo.yaml
--- old/kauth-5.70.0/metainfo.yaml      2020-05-03 00:14:56.000000000 +0200
+++ new/kauth-5.71.0/metainfo.yaml      2020-06-07 20:22:26.000000000 +0200
@@ -10,6 +10,8 @@
 deprecated: false
 release: true
 libraries:
+ - qmake: KAuthCore
+   cmake: "KF5::AuthCore"
  - qmake: KAuth
    cmake: "KF5::Auth"
 cmakename: KF5Auth
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/po/az/kauth5_qt.po 
new/kauth-5.71.0/po/az/kauth5_qt.po
--- old/kauth-5.70.0/po/az/kauth5_qt.po 1970-01-01 01:00:00.000000000 +0100
+++ new/kauth-5.71.0/po/az/kauth5_qt.po 2020-06-07 20:22:26.000000000 +0200
@@ -0,0 +1,68 @@
+# Xəyyam <[email protected]>, 2020.
+msgid ""
+msgstr ""
+"Project-Id-Version: \n"
+"PO-Revision-Date: 2020-04-09 19:42+0400\n"
+"Last-Translator: Xəyyam <[email protected]>\n"
+"Language-Team: Azerbaijani\n"
+"Language: az\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Qt-Contexts: true\n"
+"Plural-Forms: nplurals=2; plural=n != 1;\n"
+"X-Generator: Lokalize 19.12.3\n"
+
+#: backends/dbus/DBusHelperProxy.cpp:84
+#, qt-format
+msgctxt "KAuth::DBusHelperProxy|"
+msgid "DBus Backend error: service start %1 failed: %2"
+msgstr "DBus daxili xətası: %1 xidmətini başlatmaq mümkün olmadı: %2"
+
+#: backends/dbus/DBusHelperProxy.cpp:94
+#, qt-format
+msgctxt "KAuth::DBusHelperProxy|"
+msgid ""
+"DBus Backend error: connection to helper failed. %1\n"
+"(application: %2 helper: %3)"
+msgstr ""
+"DBus daxili xətası: köməkçi ilə əlaqə uğursuz oldu. %1\n"
+"(tətbiq: %2 köməkçi: %3"
+
+#: backends/dbus/DBusHelperProxy.cpp:131
+#, qt-format
+msgctxt "KAuth::DBusHelperProxy|"
+msgid ""
+"DBus Backend error: could not contact the helper. Connection error: %1. "
+"Message error: %2"
+msgstr ""
+"Dbus daxili xətası: köməkçiyə qoşulmadı. Əlaqə xətası: %1.Xəta bildirişi: %2"
+
+#: kauthexecutejob.cpp:88
+msgctxt "KAuth::ExecuteJob|"
+msgid "Tried to start an invalid action"
+msgstr "Etibarsız tapşırığı başlatmağa cəhd edildi"
+
+#: kauthexecutejob.cpp:102
+msgctxt "KAuth::ExecuteJob|"
+msgid "Unknown execution mode chosen"
+msgstr "Naməlum icra etmə rejimi seçildi"
+
+#: kauthexecutejob.cpp:147
+msgctxt "KAuth::ExecuteJob|"
+msgid "Unknown status for the authentication procedure"
+msgstr "Autentifikasiya prosedurunun naməlum vəziyyəti"
+
+#: kauthexecutejob.cpp:159
+msgctxt "KAuth::ExecuteJob|"
+msgid ""
+"The current backend only allows helper authorization, but this action does "
+"not have a helper."
+msgstr ""
+"Cari icraata icazə vermək yalnız köməkçinin köməyi ilə mümkündür, ancaq bu "
+"həmin fəaliyyət üçün mövcud deyil"
+
+#: kauthexecutejob.cpp:167 kauthexecutejob.cpp:191
+msgctxt "KAuth::ExecuteJob|"
+msgid "The backend does not specify how to authorize"
+msgstr "Bu icraat necə icazə verilməsini göstərmir"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/po/el/kauth5_qt.po 
new/kauth-5.71.0/po/el/kauth5_qt.po
--- old/kauth-5.70.0/po/el/kauth5_qt.po 2020-05-03 00:14:56.000000000 +0200
+++ new/kauth-5.71.0/po/el/kauth5_qt.po 2020-06-07 20:22:26.000000000 +0200
@@ -14,21 +14,21 @@
 # Petros Vidalis <[email protected]>, 2010, 2011.
 # Dimitrios Glentadakis <[email protected]>, 2010, 2011, 2012, 2013, 2014.
 # nikos, 2011.
-# Stelios <[email protected]>, 2012, 2013.
+# Stelios <[email protected]>, 2012, 2013, 2020.
 # Dimitris Kardarakos <[email protected]>, 2015, 2016.
 msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n";
 "POT-Creation-Date: 2014-03-23 01:50+0000\n"
-"PO-Revision-Date: 2016-11-04 17:40+0200\n"
-"Last-Translator: Dimitris Kardarakos <[email protected]>\n"
+"PO-Revision-Date: 2020-06-03 13:33+0300\n"
+"Last-Translator: Stelios <[email protected]>\n"
 "Language-Team: Greek <[email protected]>\n"
 "Language: el\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 2.0\n"
+"X-Generator: Lokalize 18.12.3\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 "X-Qt-Contexts: true\n"
 
@@ -40,14 +40,14 @@
 "Σφάλμα συστήματος υποστήριξης DBus: η εκκίνηση της υπηρεσίας %1 απέτυχε: %2"
 
 #: backends/dbus/DBusHelperProxy.cpp:94
-#, fuzzy, qt-format
-#| msgctxt "KAuth::DBusHelperProxy|"
-#| msgid "DBus Backend error: connection to helper failed. %1"
+#, qt-format
 msgctxt "KAuth::DBusHelperProxy|"
 msgid ""
 "DBus Backend error: connection to helper failed. %1\n"
 "(application: %2 helper: %3)"
-msgstr "Σφάλμα συστήματος υποστήριξης DBus: η σύνδεση με τον βοηθό απέτυχε. %1"
+msgstr ""
+"Σφάλμα συστήματος υποστήριξης DBus: η σύνδεση με τον βοηθό απέτυχε. "
+"%1(εφαρμογή: %2 βοηθός: %3)"
 
 #: backends/dbus/DBusHelperProxy.cpp:131
 #, qt-format
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/po/zh_CN/kauth5_qt.po 
new/kauth-5.71.0/po/zh_CN/kauth5_qt.po
--- old/kauth-5.70.0/po/zh_CN/kauth5_qt.po      2020-05-03 00:14:56.000000000 
+0200
+++ new/kauth-5.71.0/po/zh_CN/kauth5_qt.po      2020-06-07 20:22:26.000000000 
+0200
@@ -14,7 +14,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: kdeorg\n"
-"PO-Revision-Date: 2020-03-25 19:51\n"
+"PO-Revision-Date: 2020-05-09 13:50\n"
 "Language-Team: Chinese Simplified\n"
 "Language: zh_CN\n"
 "MIME-Version: 1.0\n"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/src/CMakeLists.txt 
new/kauth-5.71.0/src/CMakeLists.txt
--- old/kauth-5.70.0/src/CMakeLists.txt 2020-05-03 00:14:56.000000000 +0200
+++ new/kauth-5.71.0/src/CMakeLists.txt 2020-06-07 20:22:26.000000000 +0200
@@ -33,7 +33,14 @@
     )
 
     add_library(KF5AuthCore ${libkauth_core_SRCS})
-    generate_export_header(KF5AuthCore BASE_NAME KAuthCore)
+    ecm_generate_export_header(KF5AuthCore
+        BASE_NAME KAuthCore
+        GROUP_BASE_NAME KF
+        VERSION ${KF5_VERSION}
+        DEPRECATED_BASE_VERSION 0
+        DEPRECATION_VERSIONS 5.71
+        EXCLUDE_DEPRECATED_BEFORE_AND_AT ${EXCLUDE_DEPRECATED_BEFORE_AND_AT}
+    )
     add_library(KF5::AuthCore ALIAS KF5AuthCore)
     target_link_libraries(KF5AuthCore PUBLIC Qt5::Core KF5::CoreAddons)  # for 
KJob
     target_link_libraries(KF5AuthCore PRIVATE Qt5::DBus)
@@ -179,6 +186,8 @@
             KAUTH_EXPORT
             KAUTH_DEPRECATED
             KAUTH_DEPRECATED_EXPORT
+            "KAUTHCORE_DEPRECATED_VERSION(x, y, t)"
+            "KAUTHCORE_DEPRECATED_VERSION_BELATED(x, y, xt, yt, t)"
         TAGFILE_INSTALL_DESTINATION ${KDE_INSTALL_QTQCHDIR}
         QCH_INSTALL_DESTINATION ${KDE_INSTALL_QTQCHDIR}
         COMPONENT Devel
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/src/kauthaction.cpp 
new/kauth-5.71.0/src/kauthaction.cpp
--- old/kauth-5.70.0/src/kauthaction.cpp        2020-05-03 00:14:56.000000000 
+0200
+++ new/kauth-5.71.0/src/kauthaction.cpp        2020-06-07 20:22:26.000000000 
+0200
@@ -71,7 +71,7 @@
     BackendsManager::authBackend()->setupAction(d->name);
 }
 
-#ifndef KAUTHCORE_NO_DEPRECATED
+#if KAUTHCORE_BUILD_DEPRECATED_SINCE(5, 71)
 Action::Action(const QString &name, const QString &details)
     : Action(name, DetailsMap{{AuthDetail::DetailOther, details}})
 {
@@ -134,12 +134,14 @@
     d->timeout = timeout;
 }
 
-#ifndef KAUTHCORE_NO_DEPRECATED
+#if KAUTHCORE_BUILD_DEPRECATED_SINCE(5, 71)
 QString Action::details() const
 {
     return d->details.value(AuthDetail::DetailOther).toString();
 }
+#endif
 
+#if KAUTHCORE_BUILD_DEPRECATED_SINCE(5, 71)
 void Action::setDetails(const QString &details)
 {
     d->details.clear();
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/src/kauthaction.h 
new/kauth-5.71.0/src/kauthaction.h
--- old/kauth-5.70.0/src/kauthaction.h  2020-05-03 00:14:56.000000000 +0200
+++ new/kauth-5.71.0/src/kauthaction.h  2020-06-07 20:22:26.000000000 +0200
@@ -35,6 +35,8 @@
 
 class ActionData;
 /**
+ * @class Action kauthaction.h <KAuthAction>
+ *
  * @brief Class to access, authorize and execute actions.
  *
  * This is the main class of the kauth API. It provides the interface to
@@ -111,6 +113,9 @@
     };
     Q_ENUM(AuthDetail)
 
+    /**
+     * Map of details.
+     */
     typedef QMap<AuthDetail, QVariant> DetailsMap;
 
     /**
@@ -131,16 +136,17 @@
      */
     Action(const QString &name);
 
+#if KAUTHCORE_ENABLE_DEPRECATED_SINCE(5, 71)
     /**
      * This creates a new action object with this name and details
      * @param name The name of the new action
      * @param details The details of the action
      *
      * @see setDetails
-     * @deprecated since 5.68
+     * @deprecated since 5.68, use constructor with DetailsMap
      */
-#ifndef KAUTHCORE_NO_DEPRECATED
-    KAUTHCORE_DEPRECATED Action(const QString &name, const QString &details);
+    KAUTHCORE_DEPRECATED_VERSION_BELATED(5, 71, 5, 68, "Use constructor with 
DetailsMap")
+    Action(const QString &name, const QString &details);
 #endif
 
     /**
@@ -225,6 +231,7 @@
      */
     void setTimeout(int timeout);
 
+#if KAUTHCORE_ENABLE_DEPRECATED_SINCE(5, 71)
     /**
      * @brief Sets the action's details
      *
@@ -232,10 +239,10 @@
      * (if the backend supports it) on the action being authorized in
      * the authorization dialog
      *
      * @deprecated since 5.68, use setDetails() with DetailsMap.
      */
-#ifndef KAUTHCORE_NO_DEPRECATED
-    KAUTHCORE_DEPRECATED void setDetails(const QString &details);
+    KAUTHCORE_DEPRECATED_VERSION_BELATED(5, 71, 5, 68, "Use setDetailsV2() 
with DetailsMap")
+    void setDetails(const QString &details);
 #endif
 
     /**
@@ -252,6 +259,7 @@
      */
     void setDetailsV2(const DetailsMap &details);
 
+#if KAUTHCORE_ENABLE_DEPRECATED_SINCE(5, 71)
     /**
      * @brief Gets the action's details
      *
@@ -261,8 +269,8 @@
      * @return The action's details
      * @deprecated since 5.68, use detailsV2() with DetailsMap.
      */
-#ifndef KAUTHCORE_NO_DEPRECATED
-    KAUTHCORE_DEPRECATED QString details() const;
+    KAUTHCORE_DEPRECATED_VERSION_BELATED(5, 71, 5, 68, "Use detailsV2() with 
DetailsMap")
+    QString details() const;
 #endif
 
     /**
@@ -232,10 +239,10 @@
      * the authorization dialog
      *
-     * @deprecated since 5.68, use setDetails() with DetailsMap.
+     * @deprecated since 5.68, use setDetailsV2() with DetailsMap.
      */
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/src/kauthactionreply.h 
new/kauth-5.71.0/src/kauthactionreply.h
--- old/kauth-5.70.0/src/kauthactionreply.h     2020-05-03 00:14:56.000000000 
+0200
+++ new/kauth-5.71.0/src/kauthactionreply.h     2020-06-07 20:22:26.000000000 
+0200
@@ -330,6 +330,8 @@
 class ActionReplyData;
 
 /**
+ * @class ActionReply kauthactionreply.h <KAuthActionReply>
+ *
  * @brief Class that encapsulates a reply coming from the helper after 
executing
  * an action
  *
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/src/kauthexecutejob.h 
new/kauth-5.71.0/src/kauthexecutejob.h
--- old/kauth-5.70.0/src/kauthexecutejob.h      2020-05-03 00:14:56.000000000 
+0200
+++ new/kauth-5.71.0/src/kauthexecutejob.h      2020-06-07 20:22:26.000000000 
+0200
@@ -31,6 +31,8 @@
 {
 
 /**
+ * @class ExecuteJob kauthexecutejob.h <KAuthExecuteJob>
+ *
  * @brief Job for executing an Action
  *
  * To run the action synchonously use KJob::exec() and check the return code 
for
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kauth-5.70.0/src/kauthobjectdecorator.h 
new/kauth-5.71.0/src/kauthobjectdecorator.h
--- old/kauth-5.70.0/src/kauthobjectdecorator.h 2020-05-03 00:14:56.000000000 
+0200
+++ new/kauth-5.71.0/src/kauthobjectdecorator.h 2020-06-07 20:22:26.000000000 
+0200
@@ -31,6 +31,8 @@
 class ObjectDecoratorPrivate;
 
 /**
+ * @class ObjectDecorator kauthobjectdecorator.h <KAuthObjectDecorator>
+ *
  * @brief A decorator to add auth features to a button or an action
  *
  * @author Dario Freddi <[email protected]>


Reply via email to